@@ -12,12 +12,12 @@ class IDrone(IRobot, abc.ABC):
     Define all actions needed for flying a drone and declare the get_input() abstract method
     """
 
-    def __init__(self, en_devices, nen_devices, motor_devices):
+    def __init__(self, devices):
         super().__init__()
         self.name = self.getName()
         self.basic_time_step = int(self.getBasicTimeStep())
-        self.devices = self._attach_and_enable_devices(en_devices, nen_devices)
-        self.motors = self._attach_and_enable_motors(motor_devices)
+        self.devices = self._attach_and_enable_devices(devices.enableable_devices, devices.non_enableable_devices)
+        self.motors = self._attach_and_enable_motors(devices.motor_devices)
         self._cross_check_devices()
         self._cross_check_motors()
         self._set_constants()
@@ -56,7 +56,7 @@ class IDrone(IRobot, abc.ABC):
             if MotorDevice(device) == MotorDevice.CAMERA:
                 m_devices[name] = {'type': device, 'motor': self.getDevice(name), 'axis': args[0]}
             elif MotorDevice(device) == MotorDevice.PROPELLER:
-                m_devices[name] = {'type': device, 'motor': self.getDevice( name),
+                m_devices[name] = {'type': device, 'motor': self.getDevice(name),
                                    'relative_position': args[0]}
                 m_devices[name]['motor'].setPosition(float('inf'))
                 m_devices[name]['motor'].setVelocity(1.0)
