@@ -4,9 +4,6 @@ from flockai.interfaces.drone import IDrone
 
 
 class AutopilotControlledDrone(IDrone, abc.ABC):
-    def __init__(self):
-        self.flight_plan = [2, 3, 1, 4, 6]
-
     def set_flight_plan(self, plan):
         pass
 
